timeseries.SpaceCurve.lift_and_mass — GDA Toolbox v1.0 Manual

# timeseries.SpaceCurve.lift_and_mass

`SpaceCurve.` `lift_and_mass`()

  Produce the terms of the force-balance equations, to help derive coefficient-of-lift and mass from pure trajectory information.

  Consider an aircraft flying with velocity \(v\), banking angle \(\theta\), air density \(\rho\), mass \(m\), gravity \(g\), vertical acceleration \(\ddot{z}\), and lift coefficient \(C_{\text{lift}}\).

  The force-balance equation is ..math:

      LHS = \frac12 \|v\|^2 \, \cos(\theta)\, \rho
      RHS = (g + \ddot{z})
      LHS\, C_{\text{lift}} = RHS\, m

  Returns: | coefficients : :class:np.array the columns are LHS and RHS.

#### Previous topic

timeseries.SpaceCurve.featurize

#### Next topic

timeseries.SpaceCurve.lift_profile